# Fit of Breath Test Curves to Exponential beta
# Revised July 2016 for use with Stan 2.10

data{
  int<lower=0> N; # Number of data
  int<lower=0> NRecord; # Number of records
  int<lower=0> Record[N]; # From BreathTestRecordID
  real<lower=0> Time[N];
  real<lower=-30> PDR[N];
}

parameters{
  real <lower=0> m[NRecord];
  real <lower=0> k[NRecord];
  real <lower=0> beta[NRecord];
  real <lower=0> sigma;
}

model {

  int rec;
  real mn;
  real ktn;
  real kn;
  real betan;
  real pdr;

  m ~ normal(20,25);
  beta ~ normal(2,0.4);
  k ~ normal(0.0015,0.001);
  sigma ~ cauchy(0,5);

  for (n in 1:N){
    rec = Record[n];
    mn  =  m[rec];
    kn = k[rec];
    ktn = kn* Time[n];
    betan = beta[rec];
    # Fixed dose 100 assumed
    pdr = 100*mn*kn*betan*exp(-ktn) * pow(1 - exp(-ktn),(betan -1));
    PDR[n] ~ normal(pdr,sigma);
  }
}
